@@ -1,6 +1,6 @@
-#line 1 "inc/Module/Install/PRIVATE/PAR.pm - /usr/local/lib/perl5/site_perl/5.8.0/Module/Install/PRIVATE/PAR.pm"
+#line 1 "inc/Module/Install/PRIVATE/PAR.pm - /usr/local/lib/perl5/site_perl/5.8.1/Module/Install/PRIVATE/PAR.pm"
 # $File: //member/autrijus/Module-Install-PRIVATE/lib/Module/Install/PRIVATE/PAR.pm $ $Author: autrijus $
-# $Revision: #3 $ $Change: 5903 $ $DateTime: 2003/05/16 17:14:46 $ vim: expandtab shiftwidth=4
+# $Revision: #12 $ $Change: 9361 $ $DateTime: 2003/12/20 01:10:25 $ vim: expandtab shiftwidth=4
 
 package Module::Install::PRIVATE::PAR;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
@@ -16,7 +16,7 @@ sub Autrijus_PAR {
     my $cc   = $self->can_cc unless $bork;
     my $par  = $self->fetch_par('', '', !$cc) unless $cc or $bork;
     my $exe  = $Config::Config{_exe};
-    my $dynperl = $Config::Config{libperl} =~ /\b$Config::Config{dlext}$/i;
+    my $dynperl = $Config::Config{useshrplib} && ($Config::Config{useshrplib} ne 'false');
 
     if ($bork) {
         warn "Binary loading known to fail on $^O; won't generate 'script/parl$exe'!\n";
@@ -53,6 +53,7 @@ sub Autrijus_PAR {
         MAN1PODS		=> {
             'script/par.pl'	=> 'blib/man1/par.pl.1',
             'script/pp'	        => 'blib/man1/pp.1',
+            'script/tkpp'       => 'blib/man1/tkpp.1',
           ($par or $cc) ? (
             'script/parl.pod'   => 'blib/man1/parl.1',
           ) : (),
@@ -60,8 +61,12 @@ sub Autrijus_PAR {
         EXE_FILES		=> [
             'script/par.pl',
             'script/pp',
+            'script/tkpp',
           (!$par and $cc) ? (
             "script/parl$exe",
+            ($^O eq 'MSWin32' and Win32::IsWinNT()) ? (
+                "contrib/replaceicon$exe",
+            ) : (),
             $dynperl ? (
                 "script/parldyn$exe",
             ) : (),
@@ -85,7 +90,9 @@ sub Autrijus_PAR_fix {
     open IN, '< Makefile' or return;
     open OUT, '> Makefile.new' or return;
     while (<IN>) {
-        print OUT $_ unless /^\t\$\(FIXIN\) .*\Q$exe\E$/;
+        next if /^\t\$\(FIXIN\) .*\Q$exe\E$/;
+        next if /^\@\[$/ or /^\]$/;
+        print OUT $_;
     }
     close OUT;
     close IN;
